@@ -1,3 +1,15 @@
+# -*- coding: utf-8 -*-
+r"""
+GUI class to index manually laue pattern
+
+This module belongs to the open source LaueTools project with a free code repository at
+https://gitlab.esrf.fr/micha/lauetools
+mailto: micha -at* esrf *dot- fr
+
+March 2020
+"""
+from __future__ import division
+__author__ = "Jean-Sebastien Micha, CRG-IF BM32 @ ESRF"
 import sys
 import copy
 
@@ -36,20 +48,22 @@ if sys.version_info.major == 3:
     from . import threadGUI2 as TG
     from . ResultsIndexationGUI import RecognitionResultCheckBox
     from . import PlotLimitsBoard
+    from .. import imageprocessing as ImProc
 else:
     import indexingAnglesLUT as INDEX
     import indexingImageMatching as IIM
     import indexingSpotsSet as ISS
     import lauecore as LAUE
     import LaueGeometry as F2TC
-    import GUI.LaueSpotsEditor as LSEditor
     import CrystalParameters as CP
     import generaltools as GT
     import dict_LaueTools as DictLT
     import dragpoints as DGP
+    import GUI.LaueSpotsEditor as LSEditor
     from GUI.ResultsIndexationGUI import RecognitionResultCheckBox
     import GUI.threadGUI2 as TG
     import GUI.PlotLimitsBoard
+    import imageprocessing as ImProc
 
 # --- ---------------  Manual indexation Frame
 class ManualIndexFrame(wx.Frame):
@@ -99,6 +113,7 @@ class ManualIndexFrame(wx.Frame):
         self.data_dict["ImageArray"] = None
         self.data_dict["logscale"] = True
         self.data_dict["markercolor"] = "b"
+        self.data_dict["removebckg"] = False
 
         if self.data_dict["CCDLabel"] in ("MARCCD165", "ROPER"):
             # flip Y axis for marccd type image display
@@ -254,7 +269,7 @@ class ManualIndexFrame(wx.Frame):
         self.initGUI()
 
     def initGUI(self):
-
+        """ init GUI of ManualIndexFrame """
         self.sb = self.CreateStatusBar()
 
         colourb_bkg = [242, 241, 240, 255]
@@ -438,7 +453,7 @@ class ManualIndexFrame(wx.Frame):
         self.spotindexspinctrl.SetToolTipString(tipshow)
 
     def _layout(self):
-
+        """ set the widgets layout """
         lutbox = wx.BoxSizer(wx.HORIZONTAL)
         lutbox.Add(self.txtnlut, 0, wx.ALL)
         lutbox.Add(self.nlut, 0, wx.ALL)
@@ -542,14 +557,14 @@ class ManualIndexFrame(wx.Frame):
         self.Layout()
 
     def sliderUpdate_exp(self, _):
-        print("sliderUpdate_exp")
+        """handle exp. spot size slider """
         self.factorsize = int(self.slider_exp.GetValue())
         self.getlimitsfromplot = True
         self._replot()
         print("factor spot size = %f " % self.factorsize)
 
     def sliderUpdate_ps(self, _):
-        print("sliderUpdate_ps", self.slider_ps.GetValue())
+        """ handle intensity scale factor"""
         # ps from -5 5
         ps = (int(self.slider_ps.GetValue()) - 50) / 10.0
 
@@ -572,24 +587,26 @@ class ManualIndexFrame(wx.Frame):
         """
         from . PlotRefineGUI import IntensityScaleBoard
 
-        IScaleBoard = IntensityScaleBoard(self, -1, "Image scale setting Board",
-                                                                                    self.data_dict)
+        IScaleBoard = IntensityScaleBoard(self, -1, "Image scale setting Board", self.data_dict)
 
         IScaleBoard.Show(True)
 
     def OnDrawLine(self, _):
+        """ set mode on to draw line (for gnomonic data)"""
         self.addlines = True
 
         self.getlimitsfromplot = True
         self._replot()
 
     def OnClearLines(self, _):
+        """ set mode off to draw line (for gnomonic data)"""
         self.addlines = False
 
         self.getlimitsfromplot = True
         self._replot()
 
     def init_data(self):
+        """ set coordinates of spots depending on chosen representing space (self.datatype)"""
         if self.datatype == "2thetachi":
             #             self.tth, self.chi = self.Data_X, self.Data_Y
             self.tth, self.chi = self.data_2thetachi
@@ -606,6 +623,7 @@ class ManualIndexFrame(wx.Frame):
         self.Data_index_expspot = np.arange(len(self.Data_X))
 
     def reinit_data(self):
+        """ reset self.data to initial data"""
         self.data = copy.copy(self.alldata)
 
     def BuildDataDict_old(self, _):  # filter Exp Data spots
@@ -793,6 +811,7 @@ class ManualIndexFrame(wx.Frame):
             pass
 
     def SetSpotSize(self, _):
+        """ not implemented """
         wx.MessageBox("To be implemented", "info")
         pass
 
@@ -817,6 +836,7 @@ class ManualIndexFrame(wx.Frame):
         PlotLismitsBoard.Show(True)
 
     def initplotlimits(self):
+        """ set self.xlim and ylim from self.datatype and self.kf_direction and self.CCDLabel """
         if self.datatype == "2thetachi":
             self.locatespotmarkersize = 3
             if self.kf_direction == "Z>0":
@@ -851,10 +871,11 @@ class ManualIndexFrame(wx.Frame):
         self.powerscale = 1.0
 
     def setplotlimits_fromcurrentplot(self):
+        """ set self.xlim and ylim for current plot """
         self.xlim = self.axes.get_xlim()
         self.ylim = self.axes.get_ylim()
-        print("new limits x", self.xlim)
-        print("new limits y", self.ylim)
+        #print("new limits x", self.xlim)
+        #print("new limits y", self.ylim)
 
     def _replot(self):
         """
@@ -879,12 +900,14 @@ class ManualIndexFrame(wx.Frame):
         #        self.axes.cla()
 
         def fromindex_to_pixelpos_x(index, _):
+            """ return pixel pos X"""
             if self.datatype == "pixels":
                 return int(index)
             else:
                 return index
 
         def fromindex_to_pixelpos_y(index, _):
+            """ return pixel pos Y"""
             if self.datatype == "pixels":
                 return int(index)
             else:
@@ -896,6 +919,23 @@ class ManualIndexFrame(wx.Frame):
         # background image
         if self.ImageArray is not None and self.datatype == "pixels":
 
+            # array to display: raw
+            print('self.data_dict["removebckg"]',self.data_dict["removebckg"])
+            if not self.data_dict["removebckg"]:
+                self.ImageArray = self.ImageArrayInit
+            # array to display: raw - bkg
+            else:
+                if self.ImageArrayMinusBckg is None:
+                    # compute 
+                    backgroundimage = ImProc.compute_autobackground_image(self.ImageArrayInit,
+                                                                            boxsizefilter=10)
+                    # basic substraction
+                    self.ImageArrayMinusBckg = ImProc.computefilteredimage(self.ImageArrayInit,
+                                                            backgroundimage, self.CCDLabel,
+                                                            usemask=True, formulaexpression='A-B')
+                    
+                self.ImageArray = self.ImageArrayMinusBckg
+
             print("self.ImageArray", self.ImageArray.shape)
             self.myplot = self.axes.imshow(self.ImageArray, interpolation="nearest")
 
@@ -1010,15 +1050,18 @@ class ManualIndexFrame(wx.Frame):
         self.canvas.draw()
 
     def func_size_energy(self, val, factor):
+        """ spot size function from energy (val)"""
         return 400.0 * factor / (val + 1.0)
 
     def func_size_intensity(self, val, factor, offset, lin=1):
+        """ spot size (or color?) function from intensity (val)"""
         if lin:
             return 0.1 * (factor * val + offset)
         else:  # log scale
             return factor * np.log(np.clip(val, 0.000000001, 1000000000000)) + offset
 
     def func_size_peakintensity(self, intensity, params, lin=1):
+        """ spot size (or color?) function from intensity (val)"""
         if lin == 1:
             s0, slope, smin, smax = params
             s = np.clip(slope * intensity + s0, smin, smax)
@@ -1033,7 +1076,7 @@ class ManualIndexFrame(wx.Frame):
         return s
 
     def onNlut(self, _):
-
+        """ check if n<=7"""
         nlut = int(self.nlut.GetValue())
         if nlut > 7:
             dlg = wx.MessageDialog(self, "nlut must be reasonnably less or equal to 7",
@@ -1169,6 +1212,7 @@ class ManualIndexFrame(wx.Frame):
         evt.Skip()
 
     def store_pts(self, evt):
+        """ add mouse clicked point to self.points list"""
         self.points.append((evt.xdata, evt.ydata))
         print("# selected points", self.nbclick)
         print("Coordinates(%.3f,%.3f)" % (evt.xdata, evt.ydata))
@@ -1263,7 +1307,7 @@ class ManualIndexFrame(wx.Frame):
         return x, y, annote[0], annote[1]
 
     def updateStatusBar(self, x, y, annote, spottype="exp"):
-
+        """ display in status bar spot coordinates and other info"""
         if self.datatype == "2thetachi":
             Xplot = "2theta"
             Yplot = "chi"
@@ -1295,7 +1339,7 @@ class ManualIndexFrame(wx.Frame):
 
     def RemoveLastRectangle(self):
         """ remove last added rectangle """
-        if type(self.axes.patches[-1]) == type(Rectangle((1, 1), 1, 1)):
+        if isinstance(self.axes.patches[-1], Rectangle):
             del self.axes.patches[-1]
 
     def addPatchRectangle(self, X, Y, size=50):
