@@ -6,12 +6,11 @@ import os
 import sys
 import time
 
-import matplotlib
+import matplotlib as mpl
 
-matplotlib.use("WXAgg")
+#mpl.use("WXAgg")
 
 from matplotlib import __version__ as matplotlibversion
-import matplotlib as mpl
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_wxagg import (FigureCanvasWxAgg as FigCanvas,
                                                     NavigationToolbar2WxAgg as NavigationToolbar)
@@ -58,9 +57,11 @@ except ImportError:
 if sys.version_info.major == 3:
     from . import generaltools as GT
     from . IOLaueTools import ReadSpec
+    from . import MessageCommand as MC
 else:
     import generaltools as GT
     from IOLaueTools import ReadSpec
+    import MessageCommand as MC
 
 import wx.lib.agw.customtreectrl as CT
 
@@ -229,64 +230,6 @@ class TreePanel(wx.Panel):
         print("self.set_selected_indices", self.set_selected_indices)
 
 
-# --- ---------------  Plot limits board  parameters
-class MessageCommand(wx.Dialog):
-    """
-    Class to command with spec
-    """
-
-    def __init__(self, parent, _id, title, sentence=None, speccommand=None, specconnection=None):
-        """
-        initialize board window
-        """
-        wx.Dialog.__init__(self, parent, _id, title, size=(400, 250))
-
-        self.parent = parent
-        #print("self.parent", self.parent)
-
-        self.speccommand = speccommand
-
-        txt1 = wx.StaticText(self, -1, "%s\n\n%s" % (sentence, self.speccommand))
-
-        acceptbtn = wx.Button(self, -1, "OK")
-        tospecbtn = wx.Button(self, -1, "Send to Spec")
-        cancelbtn = wx.Button(self, -1, "Cancel")
-
-        acceptbtn.Bind(wx.EVT_BUTTON, self.onAccept)
-        cancelbtn.Bind(wx.EVT_BUTTON, self.onCancel)
-        tospecbtn.Bind(wx.EVT_BUTTON, self.onCommandtoSpec)
-
-        btnssizer = wx.BoxSizer(wx.HORIZONTAL)
-        btnssizer.Add(acceptbtn, 0, wx.ALL)
-        btnssizer.Add(cancelbtn, 0, wx.ALL)
-        btnssizer.Add(tospecbtn, 0, wx.ALL)
-
-        vbox = wx.BoxSizer(wx.VERTICAL)
-        vbox.Add(txt1)
-        vbox.Add(btnssizer)
-        self.SetSizer(vbox)
-
-    def onAccept(self, _):
-
-        self.Close()
-
-    def onCancel(self, _):
-
-        # todo save old positions and make inverse mvt
-        self.Close()
-
-    def onCommandtoSpec(self, _):
-
-
-        myspec = SpecCommand.SpecCommand("", "crg1:laue")
-
-        print("Sending command : " + self.speccommand)
-
-        myspec.executeCommand(self.speccommand)
-
-        self.Close()
-
-
 class MainFrame(wx.Frame):
     """
     Class main GUI
@@ -1829,7 +1772,7 @@ class ImshowPanel(wx.Panel):
                     wx.MessageBox(sentence + "\n" + command, "INFO")
 
                 # WARNING could do some instabilities to station ??
-                msgdialog = MessageCommand(self, -1, "motors command",
+                msgdialog = MC.MessageCommand(self, -1, "motors command",
                     sentence=sentence, speccommand=command, specconnection=None)
                 msgdialog.ShowModal()
 
